@@ -6,7 +6,7 @@ Created on Oct 12, 2013
 
 import logging
 from flask.globals import _request_ctx_stack
-from flask_appbuilder._compat import as_unicode
+from ._compat import as_unicode
 
 
 log = logging.getLogger(__name__)
@@ -24,7 +24,8 @@ class RenderTemplateWidget(object):
         jinja_env = ctx.app.jinja_env
         
         template = jinja_env.get_template(self.template)
-        args = dict(self.template_args.items() + kwargs.items())
+        args = self.template_args.copy()
+        args.update(kwargs)
         return template.render(args)
 
 
